@@ -1505,9 +1505,11 @@ class ValiotWorker():
         if current_env == 'dev':
             self.log(LogLevel.WARNING, 'Skipping worker readiness check in dev environment')
             return
-        initial_delay = os.environ.get('INITIAL_DELAY', 30)
-        self.log(LogLevel.INFO, f'Waiting {initial_delay} seconds before starting worker...')
-        time.sleep(int(initial_delay))
+        initial_delay = os.environ.get('INITIAL_DELAY', 60)
+        termination_period = os.environ.get('TERMINATION_PERIOD', 10)
+        total_delay = int(initial_delay) + int(termination_period)
+        self.log(LogLevel.INFO, f'Waiting {total_delay} seconds before starting worker...')
+        time.sleep(int(total_delay))
 
     def run(self, interval=1.0):
         """This function turns on the worker.
